Optimizers
==========

Optimizers are utilities that will fine-tune some aspect of the result image thumbor generates.

Even though optimizers can change images in any way, the usual use cases for these are:

* Reduce image weight in bytes;
* Improve image quality.

Built-in Optimizers
-------------------

.. toctree::
   :maxdepth: 1

   jpegtran
   gifv
